@@ -10,10 +10,16 @@
 
 .onLoad = function(libname, pkgname) {
   # nocov start
+    utils::globalVariables(c("super", "self"))
+
+  # reflections
+  x = utils::getFromNamespace("bbotk_reflections", ns = "bbotk")
+  x$optimizer_properties = c(x$optimizer_properties, "requires_model")
 
   # callbacks
   x = utils::getFromNamespace("mlr_callbacks", ns = "mlr3misc")
   x$add("mlr3fselect.backup", load_callback_backup)
+  x$add("mlr3fselect.svm_rfe", load_callback_svm_rfe)
 
   assign("lg", lgr::get_logger("bbotk"), envir = parent.env(environment()))
   if (Sys.getenv("IN_PKGDOWN") == "true") {
